@@ -1,10 +1,9 @@
-from PySide2.QtCore import Qt, Slot, QAbstractTableModel, QDate
-from PySide2.QtGui import QBrush, QFont
-from PySide2.QtWidgets import QHeaderView
+from PySide6.QtCore import Qt, Slot, QAbstractTableModel, QDate
+from PySide6.QtGui import QBrush, QFont
+from PySide6.QtWidgets import QHeaderView
 from jal.constants import Setup, CustomColor, BookAccount
-from jal.widgets.helpers import g_tr
 from jal.db.helpers import executeSQL, readSQLrecord
-from jal.db.update import JalDB
+from jal.db.db import JalDB
 
 
 class BalancesModel(QAbstractTableModel):
@@ -16,10 +15,7 @@ class BalancesModel(QAbstractTableModel):
         self._currency_name = ''
         self._active_only = True
         self._date = QDate.currentDate().endOfDay(Qt.UTC).toSecsSinceEpoch()
-        self._columns = [g_tr('BalancesModel', "Account"),
-                         g_tr('BalancesModel', "Balance"),
-                         " ",
-                         g_tr('BalancesModel', "Balance, ")]
+        self._columns = [self.tr("Account"), self.tr("Balance"), " ", self.tr("Balance, ")]
 
     def rowCount(self, parent=None):
         return len(self._data)
@@ -42,7 +38,7 @@ class BalancesModel(QAbstractTableModel):
         if role == Qt.FontRole:
             return self.data_font(index.row(), index.column())
         if role == Qt.BackgroundRole:
-            return self.data_background(index.row(), index.column())
+            return self.data_background(index.row(), index.column(), self._view.isEnabled())
         if role == Qt.TextAlignmentRole:
             if index.column() == 0 or index.column() == 2:
                 return Qt.AlignLeft
@@ -75,12 +71,13 @@ class BalancesModel(QAbstractTableModel):
             font.setItalic(True)
             return font
 
-    def data_background(self, row, column):
+    def data_background(self, row, column, enabled=True):
+        factor = 100 if enabled else 125
         if column == 3:
             if self._data[row]['unreconciled'] > 15:
-                return QBrush(CustomColor.LightRed)
+                return QBrush(CustomColor.LightRed.lighter(factor))
             if self._data[row]['unreconciled'] > 7:
-                return QBrush(CustomColor.LightYellow)
+                return QBrush(CustomColor.LightYellow.lighter(factor))
 
     def configureView(self):
         self._view.horizontalHeader().setSectionResizeMode(0, QHeaderView.Stretch)
@@ -172,6 +169,6 @@ class BalancesModel(QAbstractTableModel):
                                        [current_type, current_type_name, 0, '', 0, '', 0, sub_total, 0, 1, 1])))
         total_sum = sum([row['balance_a'] for row in self._data if row['level'] == 0])
         self._data.append(dict(zip(field_names,
-                                   [0, g_tr("BalancesModel", "Total"), 0, '', 0, '', 0, total_sum, 0, 1, 2])))
+                                   [0, self.tr("Total"), 0, '', 0, '', 0, total_sum, 0, 1, 2])))
         self.modelReset.emit()
 
